#' @name SchwaabTb2.2.1
#' @title Efeito da Concentração e Temperatura Sobre uma Taxa de Reação
#' @description Foram escolhidos três níveis de temperatura e cinco níveis
#'      de concentração distintos. São feitas três réplicas para cada
#'      condição experimental.
#' @format Um \code{data.frame} com 45 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{temp(°C)}}{Fator numérico que representa a temperatura
#'      em que a reação ocorreu.}
#'
#' \item{\code{conc(mol/l)}}{Fator numérico que representa o valor da
#'      concentração.}
#'
#' \item{\code{z1}}{[DEVE SER REMOVIDA POIS ESSA VARIÁVEL É IGUAL A
#'     TEMP, APENAS COM RÓTULOS DIFERENTES] Fator numérico que
#'     representa o valor da variável normalizada para a temperatura.}
#'
#' \item{\code{z2}}{[DEVE SER REMOVIDA POIS ESSA VARIÁVEL É IGUAL A
#'     CONC, APENAS COM RÓTULOS DIFERENTES] Fator numérico que
#'     representa o valor da variável normalizada para a concentração.}
#'
#' \item{\code{ordem}}{[OU É FATOR OU NUMÉRICO OU INTEIRO. EVITE INICIAR
#'     A DESCRIÇÃO DE UMA VARIÁVEL COM SUA REPRESENTAÇÃO NO R (INTEIRO
#'     QUE, NUMÉRICO QUE, FATOR QUE, ETC.)] Fator numérico inteiro que
#'     representa o número do ordenamento aleatório.}
#'
#' \item{\code{e}}{[ESSE NÃO É UM RESULTADO? POIS DIFICILMENTE SE
#'     OBSERVA UM SINAL ALEATÓRIO] Fator numérico que representa um
#'     sinal aleatório com distribuição normal, média igual a zero e
#'     desvio padrão igual a 0.1.}
#'
#' \item{\code{rc(mol/l.h)}}{Fator numérico que representa o valor da
#'     taxa de reação em função da concentração.}
#'
#' \item{\code{rexp(mol/l.h)}}{Fator numérico que representa o valor da
#'     taxa de reação em função da temperatura.}
#'
#' }
#' @keywords DBC
#' @source Schwaab, M., Pinto, J. C.(2007). Análise de Dados
#'     Experimentais I. Rio de Janeiro, RJ. COPPE UFRJ e-papers.
#' @examples
#'
#' data(SchwaabTb2.2.1)
#' str(SchwaabTb2.2.1)
#'
#' library(lattice)
#' xyplot(rc ~ rexp,
#'        groups = temp ,
#'        auto.key = list(
#'            title = "Temperaturas",
#'            cex.title = 1,
#'            columns = 3),
#'        type = c("a", "p"),
#'        data = SchwaabTb2.2.1,
#'        ylab = "Reação em função da temperatura ",
#'        xlab = "Reação em função da concentração")
#'
NULL
