#' @name SchwaabTb2.2.15
#' @title Atividade Enzimática em Problema Biotecnológico
#' @description Resultados de um experimento fatorial \eqn{3^2},
#'     realizado sob delineamento inteiramente casualizado com três
#'     repetições, com o objetivo de identificar as combinações de
#'     temperatura e potencial hidrogeniônico (pH) que resultam em uma
#'     maior atividade enzimática, expressas como gramas de produto
#'     produzido por um miligrama de enzima em uma hora.
#' @format Um \code{data.frame} com 27 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{ordem}}{Identifica a ordem de coleta das observações.}
#'
#' \item{\code{temp}}{Níveis de temperatura experimentados, registrados
#'     em graus Celsius.}
#'
#' \item{\code{ph}}{Níveis de potencial hidrogeniônico (pH)
#'     experimentados.}
#'
#' \item{\code{ativ}}{Atividade enzimática do solo, mensurada pelas
#'     gramas de produto produzido por um miligrama de enzima em uma
#'     hora \eqn{g\,(mg\,h)^{-1}}.}
#'
#' }
#'
#' @note Embora a variável \code{ativ} represente produção, valores
#'     negativos foram registrados. Não há justificativas sobre tais
#'     valores na descrição do experimento.
#'
#' @keywords FAT2K
#' @source Schwaab, M., Pinto, J. C.(2007). Análise de Dados
#'     Experimentais II. Rio de Janeiro, RJ. COPPE UFRJ e-papers.
#' @examples
#'
#' data(SchwaabTb2.2.15)
#' str(SchwaabTb2.2.15)
#'
#' means <- aggregate(ativ ~ temp + ph, data = SchwaabTb2.2.15, mean)
#' xtabs(ativ ~ ., data = means)
#'
#' library(lattice)
#' xyplot(ativ ~ temp, groups = ph,
#'        data = SchwaabTb2.2.15,
#'        type = c("g", "p", "a"),
#'        xlab = expression("Temperatura em"~degree*"C"),
#'        ylab = expression("Atividade enzimátiva em"~g~(mg~h)^{-1}),
#'        auto.key = list(
#'            title = "pH",
#'            cex.title = 1.1,
#'            column = 3,
#'            lines = TRUE
#'        ))
#'
NULL
