#' @name SchwaabTb2.2.7
#' @title Efeito da Concentração Molar e Temperatura Sobre Taxa de
#'     Reação
#' @description Resultados de um experimento em arranjo fatorial
#'     \eqn{2^2}, realizado sob delineamento inteiramente casualizado
#'     com três réplicas de cada condição experimental. Os fatores
#'     experimentados foram temperatura e concentração de uma solução
#'     não informada, com interesse de avaliar qual o efeito causado
#'     sobre a taxa de reação.
#' @format Um \code{data.frame} com 12 observações e 4 variáveis, em que
#'
#' \describe{
#'
#'  \item{\code{ordem}}{Identifica a ordem de coleta das observações.}
#'
#' \item{\code{temp}}{Níveis de temperatura em que a reação ocorreu,
#'     registrados em graus Celsius.}
#'
#' \item{\code{conc}}{Níveis de concentração em \eqn{mol/L} da solução.}
#'
#' \item{\code{reac}}{Taxa de reação, mensurada em \eqn{mol/L.h}.}
#'
#' }
#'
#' @note Na tabela 2.7 do Capítulo 2 de Schwaab e Pinto (2007) são
#'     exibidos também quantidades denominadas como \eqn{\varepsilon},
#'     erro aleatório e \eqn{R^c}. Essas são quantidades decorrentes da
#'     equação de Arrhenius, que nesse experimento, descreve
#'     teoricamente a taxa de reação como
#'     \deqn{R^c = 1000\exp \left ( -\frac{2500}{\texttt{temp}+273,15}
#'     \right ) \texttt{conc}}
#'     Assim o valor observado da taxa de reação, \code{reac} pode ser
#'     obtido com \eqn{R^c + \varepsilon}. Nesse \emph{dataset} optou-se
#'     somente pela inclusão da taxa de reação observada uma vez que
#'     essa é a quantidade efetivamente utilizada nas análises e as
#'     demais podem ser obtidas a partir dela.
#'
#' @keywords FAT2K
#' @source Schwaab, M., Pinto, J. C.(2007). Análise de Dados
#'     Experimentais II. Rio de Janeiro, RJ. COPPE UFRJ e-papers.
#' @examples
#'
#' data(SchwaabTb2.2.7)
#' str(SchwaabTb2.2.7)
#'
#' means <- aggregate(reac ~ temp + conc, data = SchwaabTb2.2.7, mean)
#' xtabs(reac ~ ., data = means)
#'
#' library(lattice)
#' xyplot(reac ~ temp, groups = conc,
#'        data = SchwaabTb2.2.7,
#'        type = c("g", "p", "a"),
#'        xlab = expression("Temperatura em"~degree*"C"),
#'        ylab = "Taxa de reação",
#'        auto.key = list(
#'            corner = c(0.1, 0.95),
#'            title = "Concentração em mol/L",
#'            cex.title = 1,
#'            lines = TRUE
#'        ))
#'
NULL
